@@ -126,7 +126,6 @@ pub async fn get_raw(
     }
 }
 
-
 #[get("/api/thumb/{hash}")]
 pub async fn get_thumbnail(
     state: web::Data<State>,
@@ -165,19 +164,11 @@ pub async fn get_thumbnail(
     Err(error::ErrorNotImplemented("Previews not enabled."))
 }
 
-#[derive(Deserialize)]
-pub struct QueryRequest {
-    query: String,
-}
-
-#[get("/api/obj")]
-pub async fn get_query(
-    state: web::Data<State>,
-    web::Query(info): web::Query<QueryRequest>,
-) -> Result<HttpResponse, Error> {
+#[post("/api/query")]
+pub async fn get_query(state: web::Data<State>, query: String) -> Result<HttpResponse, Error> {
     let connection = state.upend.connection().map_err(ErrorInternalServerError)?;
 
-    let in_query: Query = info.query.as_str().parse().map_err(ErrorBadRequest)?;
+    let in_query: Query = query.parse().map_err(ErrorBadRequest)?;
     let entries = connection
         .query(in_query)
         .map_err(ErrorInternalServerError)?;
