@@ -10,7 +10,7 @@ const inFlightRequests: { [key: string]: Promise<UpListing> } = {};
 
 export function useEntity(address: string) {
   const { data, error, revalidate } = useSWR<ListingResult, unknown>(
-    `/api/obj/${address}`
+    `api/obj/${address}`
   );
 
   const entity: Readable<UpObject | undefined> = derived(data, ($listing) => {
@@ -28,7 +28,7 @@ export function useEntity(address: string) {
 }
 
 export async function fetchEntry(address: string) {
-  const response = await fetch(`/api/raw/${address}`);
+  const response = await fetch(`api/raw/${address}`);
   const data = await response.json();
   const listing = new UpListing({ address: data });
   return listing.entries[0];
@@ -37,7 +37,7 @@ export async function fetchEntry(address: string) {
 export function query(query: string) {
   console.debug(`Querying: ${query}`);
   const { data, error, revalidate } = useSWR<ListingResult, unknown>(
-    "/api/query",
+    "api/query",
     { method: "POST", body: query }
   );
 
@@ -58,7 +58,7 @@ export async function queryOnce(query: string): Promise<UpListing> {
     if (!inFlightRequests[query]) {
       console.debug(`Querying: ${query}`);
       inFlightRequests[query] = new Promise((resolve, reject) => {
-        fetch("/api/query", { method: "POST", body: query, keepalive: true })
+        fetch("api/query", { method: "POST", body: query, keepalive: true })
           .then(async (response) => {
             resolve(new UpListing(await response.json()));
           })
