@@ -3,15 +3,15 @@ import { writable } from "svelte/store";
 // stale shim until https://github.com/ConsoleTVs/sswr/issues/24 is resolved
 export type SWRKey = string;
 export function useSWR<D = unknown, E = Error>(
-  key: SWRKey | undefined | (() => SWRKey | undefined)
+  key: SWRKey,
+  options?: RequestInit
 ) {
   const data = writable<D | undefined>();
   const error = writable<E | undefined>();
 
   async function doFetch() {
-    const keyString = typeof key === "string" ? key : key();
     try {
-      const response = await fetch(keyString);
+      const response = await fetch(key, options);
       if (response.ok) {
         data.set(await response.json());
       } else {
