@@ -2,7 +2,7 @@ import { readable, Readable } from "svelte/store";
 import type { VaultInfo } from "upend/types";
 
 export const vaultInfo: Readable<VaultInfo> = readable(undefined, (set) => {
-  fetch("/api/info").then(async (response) => {
+  fetch("api/info").then(async (response) => {
     set(await response.json());
   });
 });
