@@ -25,7 +25,7 @@ export async function getObjects(
 }
 
 export async function createLabelled(label: string) {
-  const response = await fetch(`/api/obj`, {
+  const response = await fetch(`api/obj`, {
     method: "PUT",
     headers: { "Content-Type": "application/json" },
     body: JSON.stringify({
